@@ -30,3 +30,13 @@ class TestPoints(PlotTester, metaclass=PlotTesterMeta):
 
     def test_plot_coloring_with_cmap(self, sdata_blobs: SpatialData):
         sdata_blobs.pl.render_points(color="genes", cmap="rainbow").pl.show()
+
+    def test_plot_can_stack_render_points(self, sdata_blobs: SpatialData):
+        (
+            sdata_blobs.pl.render_points(elements="blobs_points", na_color="red", size=30)
+            .pl.render_points(elements="blobs_points", na_color="blue", size=10)
+            .pl.show()
+        )
+
+    def test_plot_color_recognises_actual_color_as_color(self, sdata_blobs: SpatialData):
+        sdata_blobs.pl.render_points(elements="blobs_points", color="red").pl.show()
